@@ -2,7 +2,7 @@ import h5py
 import numpy as np
 from numba import njit, prange
 
-from ctapipe.core import Component
+from lstchain.ctapipe_compat import Component
 from ctapipe.core.traits import Int, Unicode
 
 __all__ = [
@@ -13,7 +13,6 @@ __all__ = [
 
 high_gain = 0
 low_gain = 1
-
 n_gain = 2
 n_channel = 7
 n_modules = 265
@@ -91,6 +90,35 @@ class PulseTimeCorrection(Component):
                                 self.n_capacitors)
         return pulse_corr
 
+    def get_pulse_time_corrections(self, event):
+        """
+        Return pulse time after time correction.
+        Parameters
+        ----------
+        event : `ctapipe` event-container
+
+        Return
+        ------
+        pulse_time_corrections (to be subtrated) : ndarray
+            Pulse time stored in a numpy array of shape
+            (n_gain, n_pixels).
+        """
+        pixel_ids = event.lst.tel[self.tel_id].svc.pixel_ids
+        n_modules_from_event = event.lst.tel[self.tel_id].svc.num_modules
+        pulse_time_corrections = np.empty((n_gain, n_pixels))
+        for nr in prange(0, n_modules_from_event):
+            self.first_cap_array[nr, :, :] = self.get_first_capacitor(event, nr)
+        self.get_pulse_time_correction_jit(pulse_time_corrections,
+                                pixel_ids,
+                                self.first_cap_array,
+                                self.fan_array,
+                                self.fbn_array,
+                                self.n_harmonics,
+                                self.n_capacitors)
+        return pulse_time_corrections
+
+
+
     @staticmethod
     @njit(parallel=True)
     def get_corr_pulse_jit(pulse, pulse_corr, pixel_ids, first_capacitor, fan_array, fbn_array, n_harmonics, n_cap):
@@ -131,6 +159,44 @@ class PulseTimeCorrection(Component):
                                                                                      fbn_array[gain, pixel],
                                                                                      n_harmonics,
                                                                                      n_cap)
+    @staticmethod
+    @njit(parallel=True)
+    def get_pulse_time_correction_jit(time_corrections, pixel_ids, first_capacitor, fan_array, fbn_array, n_harmonics, n_cap):
+        """
+        Numba function for pulse time correction.
+        Parameters
+        ----------
+
+        time_corrections : ndarray
+            Pulse correction time stored in a numpy array of shape
+            (n_gain, n_pixels).
+        pixel_ids: ndarray
+            Array stored expected pixel id
+            (n_pixels).
+        first_capacitor : ndarray
+            Value of first capacitor stored in a numpy array of shape
+            (n_clus, n_gain, n_pix).
+        fan_array : ndarray
+            Array to store coeff for Fourier series expansion
+            stored in a numpy array of shape
+            (n_gain, n_pixels, n_harmonics).
+        fbn_array : ndarray
+            Array to store coeff for Fourier series expansion
+            stored in a numpy array of shape
+            (n_gain, n_pixels, n_harmonics).
+        n_harmonics : int
+            Number of harmonics
+        """
+        for gain in prange(0, n_gain):
+            for nr in prange(0, n_modules):
+                for pix in prange(0, n_channel):
+                    fc = first_capacitor[nr, gain, pix]
+                    pixel = pixel_ids[nr * 7 + pix]
+                    time_corrections[gain, pixel] = get_corr_time_jit(fc % n_cap,
+                                                                      fan_array[gain, pixel],
+                                                                      fbn_array[gain, pixel],
+                                                                      n_harmonics,
+                                                                      n_cap)
 
     def get_first_capacitor(self, event, nr):
         """
