@@ -1,6 +1,6 @@
 import numpy as np
 import astropy.units as u
-from lstchain.calib.camera.flatfield import *
+from lstchain.calib.camera.flatfield import FlasherFlatFieldCalculator
 from ctapipe.containers import ArrayEventContainer
 from traitlets.config.loader import Config
 from ctapipe.instrument import SubarrayDescription, TelescopeDescription
@@ -10,9 +10,10 @@ def test_flasherflatfieldcalculator():
     """test of flasherFlatFieldCalculator"""
     tel_id = 0
     n_gain = 2
-    n_events = 10
+    n_events = 1000
     n_pixels = 1855
     ff_level = 10000
+    ff_std = 10
 
     subarray = SubarrayDescription(
         "test array",
@@ -48,19 +49,21 @@ def test_flasherflatfieldcalculator():
     data.r1.tel[tel_id].waveform = np.zeros((n_gain, n_pixels, 40), dtype=np.float32)
     # data.r1.tel[tel_id].trigger_time = 1000
 
-    # flat-field signal put == delta function of height ff_level at sample 20
-    data.r1.tel[tel_id].waveform[:, :, 20] = ff_level
-    print(data.r1.tel[tel_id].waveform[0, 0, 20])
+    rng = np.random.default_rng(0)
 
     # First test: good event
     while ff_calculator.num_events_seen < n_events:
+        # flat-field signal put == delta function of height ff_level at sample 20
+        data.r1.tel[tel_id].waveform[:, :, 20] = rng.normal(ff_level, ff_std)
+
         if ff_calculator.calculate_relative_gain(data):
             assert data.mon.tel[tel_id].flatfield
 
             print(data.mon.tel[tel_id].flatfield)
-            assert np.mean(data.mon.tel[tel_id].flatfield.charge_median) == ff_level
-            assert np.mean(data.mon.tel[tel_id].flatfield.relative_gain_median) == 1
-            assert np.mean(data.mon.tel[tel_id].flatfield.relative_gain_std) == 0
+            assert np.isclose(np.mean(data.mon.tel[tel_id].flatfield.charge_median), ff_level, rtol=0.01)
+            assert np.isclose(np.mean(data.mon.tel[tel_id].flatfield.charge_std), ff_std, rtol=0.05)
+            assert np.isclose(np.mean(data.mon.tel[tel_id].flatfield.relative_gain_median), 1, rtol=0.01)
+            assert np.isclose(np.mean(data.mon.tel[tel_id].flatfield.relative_gain_std), 0, rtol=0.01)
 
     # Second test: introduce some failing pixels
     failing_pixels_id = np.array([10, 20, 30, 40])
