@@ -9,7 +9,7 @@ separation of events stored in a DL1 file.
 
 Usage:
 
-$> python lstchain_dl1_to_dl2.py 
+$> python lstchain_dl1_to_dl2.py
 --input-file dl1_LST-1.Run02033.0137.h5
 --path-models ./trained_models
 
@@ -18,7 +18,6 @@ $> python lstchain_dl1_to_dl2.py
 import argparse
 import os
 
-import joblib
 import numpy as np
 import pandas as pd
 from ctapipe.instrument import SubarrayDescription
@@ -38,7 +37,9 @@ from lstchain.io.io import (
     dl1_images_lstcam_key,
     dl1_params_lstcam_key,
     dl1_params_src_dep_lstcam_key,
+    dl1_likelihood_params_lstcam_key,
     dl2_params_src_dep_lstcam_key,
+    dl2_likelihood_params_lstcam_key,
     write_dataframe,
 )
 from lstchain.reco import dl1_to_dl2
@@ -83,6 +84,13 @@ def main():
 
     data = pd.read_hdf(args.input_file, key=dl1_params_lstcam_key)
 
+    if 'lh_fit_config' in config.keys():
+        lhfit_data = pd.read_hdf(args.input_file, key=dl1_likelihood_params_lstcam_key)
+        if np.all(lhfit_data['obs_id'] == data['obs_id']) & np.all(lhfit_data['event_id'] == data['event_id']):
+            lhfit_data.drop({'obs_id', 'event_id'}, axis=1, inplace=True)
+        lhfit_keys = lhfit_data.keys()
+        data = pd.concat([data, lhfit_data], axis=1)
+
     # if real data, add deltat t to dataframe keys
     data = add_delta_t_key(data)
 
@@ -96,21 +104,14 @@ def main():
             data.alt_tel = - np.pi / 2.
             data.az_tel = - np.pi / 2.
 
-    # Load the trained RF for reconstruction:
+    # Get trained RF path for reconstruction:
     file_reg_energy = os.path.join(args.path_models, 'reg_energy.sav')
-    reg_energy = joblib.load(file_reg_energy)
-
     file_cls_gh = os.path.join(args.path_models, 'cls_gh.sav')
-    cls_gh = joblib.load(file_cls_gh)
-
     if config['disp_method'] == 'disp_vector':
         file_disp_vector = os.path.join(args.path_models, 'reg_disp_vector.sav')
-        reg_disp_vector = joblib.load(file_disp_vector)
     elif config['disp_method'] == 'disp_norm_sign':
         file_disp_norm = os.path.join(args.path_models, 'reg_disp_norm.sav')
         file_disp_sign = os.path.join(args.path_models, 'cls_disp_sign.sav')
-        reg_disp_norm = joblib.load(file_disp_norm)
-        cls_disp_sign = joblib.load(file_disp_sign)
 
     subarray_info = SubarrayDescription.from_hdf(args.input_file)
     tel_id = config["allowed_tels"][0] if "allowed_tels" in config else 1
@@ -129,12 +130,12 @@ def main():
                              )
 
         if config['disp_method'] == 'disp_vector':
-            dl2 = dl1_to_dl2.apply_models(data, cls_gh, reg_energy, reg_disp_vector=reg_disp_vector,
+            dl2 = dl1_to_dl2.apply_models(data, file_cls_gh, file_reg_energy, reg_disp_vector=file_disp_vector,
                                           focal_length=focal_length,
                                           custom_config=config)
         elif config['disp_method'] == 'disp_norm_sign':
-            dl2 = dl1_to_dl2.apply_models(data, cls_gh, reg_energy, reg_disp_norm=reg_disp_norm,
-                                          cls_disp_sign=cls_disp_sign,
+            dl2 = dl1_to_dl2.apply_models(data, file_cls_gh, file_reg_energy, reg_disp_norm=file_disp_norm,
+                                          cls_disp_sign=file_disp_sign,
                                           focal_length=focal_length, custom_config=config)
 
     # Source-dependent analysis
@@ -164,14 +165,13 @@ def main():
                                                    )
 
             if config['disp_method'] == 'disp_vector':
-                dl2_df = dl1_to_dl2.apply_models(data_with_srcdep_param, cls_gh, reg_energy,
-                                                 reg_disp_vector=reg_disp_vector,
+                dl2_df = dl1_to_dl2.apply_models(data_with_srcdep_param, file_cls_gh, file_reg_energy,
+                                                 reg_disp_vector=file_disp_vector,
                                                  focal_length=focal_length, custom_config=config)
             elif config['disp_method'] == 'disp_norm_sign':
-                dl2_df = dl1_to_dl2.apply_models(data_with_srcdep_param, cls_gh, reg_energy,
-                                                 reg_disp_norm=reg_disp_norm,
-                                                 cls_disp_sign=cls_disp_sign, focal_length=focal_length,
-                                                 custom_config=config)
+                dl2_df = dl1_to_dl2.apply_models(data_with_srcdep_param, file_cls_gh, file_reg_energy,
+                                                 reg_disp_norm=file_disp_norm, cls_disp_sign=file_disp_sign,
+                                                 focal_length=focal_length, custom_config=config)
 
             dl2_srcdep = dl2_df.drop(srcindep_keys, axis=1)
             dl2_srcdep_dict[k] = dl2_srcdep
@@ -180,7 +180,7 @@ def main():
                 dl2_srcindep = dl2_df[srcindep_keys]
 
     os.makedirs(args.output_dir, exist_ok=True)
-    output_file = os.path.join(args.output_dir, os.path.basename(args.input_file).replace('dl1', 'dl2'))
+    output_file = os.path.join(args.output_dir, os.path.basename(args.input_file).replace('dl1', 'dl2', 1))
 
     if os.path.exists(output_file):
         raise IOError(output_file + ' exists, exiting.')
@@ -196,6 +196,9 @@ def main():
     if dl1_params_src_dep_lstcam_key in dl1_keys:
         dl1_keys.remove(dl1_params_src_dep_lstcam_key)
 
+    if dl1_likelihood_params_lstcam_key in dl1_keys:
+        dl1_keys.remove(dl1_likelihood_params_lstcam_key)
+
     metadata = global_metadata()
     write_metadata(metadata, output_file)
 
@@ -220,7 +223,13 @@ def main():
 
     # need container to use lstchain.io.add_global_metadata and lstchain.io.add_config_metadata
     if not config['source_dependent']:
-        write_dl2_dataframe(dl2, output_file, config=config, meta=metadata)
+        if 'lh_fit_config' not in config.keys():
+            write_dl2_dataframe(dl2, output_file, config=config, meta=metadata)
+        else:
+            dl2_onlylhfit = dl2[lhfit_keys]
+            dl2.drop(lhfit_keys, axis=1, inplace=True)
+            write_dl2_dataframe(dl2, output_file, config=config, meta=metadata)
+            write_dataframe(dl2_onlylhfit, output_file, dl2_likelihood_params_lstcam_key, config=config, meta=metadata)
 
     else:
         write_dl2_dataframe(dl2_srcindep, output_file, config=config, meta=metadata)
