@@ -74,7 +74,7 @@ parser.add_argument(
 
 parser.add_argument(
     '--no-image', action='store_true',
-    help='Boolean. True to remove the images in output file',
+    help='Pass this argument to avoid writing the images in the new DL1 files. Beware, if `increase_nsb` or `increase_psf` are True in the config, the images will not be written.',
 )
 
 parser.add_argument(
@@ -92,7 +92,7 @@ def main():
     logging.getLogger().addHandler(handler)
 
     if Path(args.output_file).exists():
-        log.critical('Outputfile already exists')
+        log.critical(f'Output file {args.output_file} already exists')
         sys.exit(1)
 
     std_config = get_standard_config()
@@ -118,7 +118,7 @@ def main():
         transition_charge = imconfig["transition_charge"]
         extra_noise_in_bright_pixels = imconfig["extra_noise_in_bright_pixels"]
         smeared_light_fraction = imconfig["smeared_light_fraction"]
-        if (increase_nsb or increase_psf) and args.no_image is False:
+        if (increase_nsb or increase_psf):
             log.info("NOTE: Using the image_modifier options means images will "
                      "not be saved.")
             args.no_image = True
@@ -193,7 +193,8 @@ def main():
         'time_gradient',
         'n_pixels',
         'wl',
-        'log_intensity'
+        'log_intensity',
+        'sin_az_tel'
     ]
 
     nodes_keys = get_dataset_keys(args.input_file)
@@ -317,7 +318,8 @@ def main():
                         dl1_container['x'].to_value(u.m),
                         dl1_container['y'].to_value(u.m),
                         params['src_x'][ii],
-                        params['src_y'][ii]
+                        params['src_y'][ii],
+                        dl1_container['psi'].to_value(u.rad)
                     )
 
                     dl1_container['disp_dx'] = disp_dx
@@ -326,6 +328,8 @@ def main():
                     dl1_container['disp_angle'] = disp_angle
                     dl1_container['disp_sign'] = disp_sign
 
+                dl1_container['sin_az_tel'] = np.sin(params['az_tel'][ii])
+                    
                 for p in parameters_to_update:
                     params[ii][p] = u.Quantity(dl1_container[p]).value
 
